@@ -46,10 +46,10 @@ def writeMatrix(basename, mat, firstRow=1, firstCol=1, suffix=None,
     if basename not in bak:
         name = (basename + '_' + str(firstRow) + '_' + str(firstCol)
                 + '_' + str(mat.shape[0]) + '_' + str(mat.shape[1]))
-        bak[basename] = {'type': 'matrix', 'suffix': suffix,
-                         'name': name,
-                         'value': curMat, 'firstRow': firstRow,
-                         'firstCol': firstCol, 'tramp': tramp, 'sno': len(bak)}
+        bak[name] = {'type': 'matrix', 'suffix': suffix,
+                     'basename': basename,
+                     'value': curMat, 'firstRow': firstRow,
+                     'firstCol': firstCol, 'tramp': tramp, 'sno': len(bak)}
     if tramp is not None:
         # Special case, changing filter gains, can use TRAMP
         rampYourself = True
@@ -103,7 +103,7 @@ def writeMatrix(basename, mat, firstRow=1, firstCol=1, suffix=None,
 
 
 def restoreMatrix(bakVal):
-    writeMatrix(basename=bakVal['name'], suffix=bakVal['suffix'],
+    writeMatrix(basename=bakVal['basename'], suffix=bakVal['suffix'],
                 mat=bakVal['value'], firstCol=bakVal['firstCol'],
                 firstRow=bakVal['firstRow'], tramp=bakVal['tramp'], bak={})
 
